/**
 * DREAM
 * Copyright (C) 2003 2004 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: dream@objectweb.org
 *
 * Initial developer(s): Matthieu Leclercq
 * Contributor(s): 
 */

package org.objectweb.dream.channel;

import org.objectweb.fractal.api.control.AttributeController;
import org.objectweb.fractal.api.control.IllegalLifeCycleException;

/**
 * Attribute controller for IP channel in, It defines a listening port number
 * attribute.
 */
public interface IPChannelInAttributeController extends AttributeController
{

  /**
   * Returns the listening port.
   * 
   * @return the listening port.
   */
  int getListeningPort();

  /**
   * Sets the listening port.
   * 
   * @param port the listening port.
   * @throws IllegalLifeCycleException cannot change port number if the
   *           component is started.
   */
  void setListeningPort(int port) throws IllegalLifeCycleException;

  /**
   * Returns the number of attempts to open a {@link java.net.ServerSocket }
   * before aborting.
   * 
   * @return the number of attempts to open a {@link java.net.ServerSocket }
   *         before aborting.
   */
  int getOpenRetry();

  /**
   * Sets the number of attempts to open a {@link java.net.ServerSocket }before
   * aborting.
   * 
   * @param retry the number of attempts to open a
   *          {@link java.net.ServerSocket }before aborting.
   */
  void setOpenRetry(int retry);
}