/**
 * DREAM
 * Copyright (C) 2003 2004 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: dream@objectweb.org
 *
 * Initial developer(s): Matthieu Leclercq
 * Contributor(s): 
 */

package org.objectweb.dream.channel;

/**
 * Attribute controller for {@link MultiConnTCPChannelOutImpl }component.
 * Defines attribute to control the maximum number of connections.
 */
public interface MultiConnTCPChannelOutAttributeController
    extends
    MultiDestinationChannelOutAttributeController
{

  /**
   * Sets the maximum number of connections.
   * 
   * @param maxConnection the maximum number of connections.
   */
  void setMaxConnection(int maxConnection);

  /**
   * Returns the maximum number of connections.
   * 
   * @return the maximum number of connections.
   */
  int getMaxConnection();

  /**
   * Sets the <code>SO_TIMEOUT</code>.
   * 
   * @param timeout timeout, in milliseconds. if negative, use default value.
   * @see java.net.Socket#setSoTimeout(int)
   */
  void setSoTimeout(int timeout);

  /**
   * Returns the <code>SO_TIMEOUT</code>.
   * 
   * @return timeout, in milliseconds.
   */
  int getSoTimeout();
}