/**
 * DREAM
 * Copyright (C) 2003 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: matthieu.leclercq@inrialpes.fr
 *
 * Initial developer(s): Matthieu Leclercq
 * Contributor(s): Vivien Quema
 */

package org.objectweb.dream.channel;

import java.io.IOException;
import java.io.InputStream;
import java.net.Socket;

import org.objectweb.util.monolog.api.BasicLevel;

/**
 * Reliable implementation of a ChannelOut component, using TCP protocol and
 * {@link java.net.InetSocketAddress}destination. The ChannelOut waits for an
 * ACK to arrive after the message has been sent.
 */
public class ReliableTCPChannelOutImpl extends BasicTCPChannelOutImpl
{

  /**
   * Waits for an ACK to arrive.
   * 
   * @param sock the socket to be used to wait for the ack.
   * @throws IOException if an error occurs.
   */
  protected void receiveAck(Socket sock) throws IOException
  {
    InputStream is = sock.getInputStream();
    logger.log(BasicLevel.DEBUG, "wait ack");
    int ret = is.read();
    if (ret == -1)
    {
      throw new IOException("Connection broken");
    }
    logger.log(BasicLevel.DEBUG, "received ack");
    is.close();
  }

}