/**
 * Copyright (C) 2002
 */

package org.objectweb.util.monolog.wrapper.config;

import org.objectweb.util.monolog.api.Handler;

import java.util.Map;
import java.util.HashMap;
import java.io.Serializable;

/**
 * This class is a basic implementation the Handler interface. It is not linked
 * to any underlying log system. Therefore all attributes are stored into
 * internal struture.
 *
 * @author Sebastien Chassande-Barrioz
 */
public class BasicHandler implements Handler, Serializable {

	/**
	 * The name of the handler
	 */
	protected String name = null;

	/**
	 * The attributes of the handler are listed by this field.
	 * key = atribute name
	 * value = attribute value
	 */
	protected HashMap attributes = null;

	/**
	 * The type of the handler
	 */
	protected byte type = 0;

	public BasicHandler(String n, byte t) {
		type = t;
		name = n;
		attributes = new HashMap();
	}

	public Map getAttributes() {
		return attributes;
	}

	public void setAttributes(Map properties) {
		attributes.clear();
		attributes.putAll(properties);
	}

	// IMPLEMENTATION OF THE Handler INTERFACE //
	//-----------------------------------------//

	public String getName() {
		return name;
	}

	public void setName(String n) {
		name = n;
	}

	public byte getType() {
		return type;
	}

	public String[] getAttributeNames() {
		return (String[]) attributes.keySet().toArray(new String[0]);
	}

	public Object getAttribute(String key) {
		return attributes.get(key);
	}

	public Object setAttribute(String key, Object value) {
		return attributes.put(key, value);
	}
}
